@@ -1,7 +1,8 @@
 #!/bin/sh
+export PATH='/usr/obj/hs-MonadCatchIO-mtl-0.3.1.0/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: MonadCatchIO-mtl
-version: 0.3.0.5
-id: MonadCatchIO-mtl-0.3.0.5-50eb20252600070062edde5090a7ae72
+version: 0.3.1.0
+id: MonadCatchIO-mtl-0.3.1.0-302ee90ea16ac5204cc7483e0197ef9d
 
 license: BSD3
 copyright:
@@ -21,21 +22,21 @@ exposed: True
 exposed-modules: Control.Monad.CatchIO
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/MonadCatchIO-mtl-0.3.0.5
-library-dirs: /usr/local/lib/ghc/MonadCatchIO-mtl-0.3.0.5
-hs-libraries: HSMonadCatchIO-mtl-0.3.0.5
+import-dirs: /usr/local/lib/ghc/MonadCatchIO-mtl-0.3.1.0
+library-dirs: /usr/local/lib/ghc/MonadCatchIO-mtl-0.3.1.0
+hs-libraries: HSMonadCatchIO-mtl-0.3.1.0
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
-         extensible-exceptions-0.1.1.4-3d9bd197c43329612c640f24179a7f19
-         mtl-2.1.2-02e701f9b1590ee88a0b5b0bd5d93a29
+depends: MonadCatchIO-transformers-0.3.1.2-62247321324d3e4a539fd9759ef95eea
+         base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
+         extensible-exceptions-0.1.1.4-ff00541964e8b4f6fe7adae94cd5f3b4
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-MonadCatchIO-mtl-0.3.0.5/html/MonadCatchIO-mtl.haddock
-haddock-html: /usr/local/share/doc/hs-MonadCatchIO-mtl-0.3.0.5/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-MonadCatchIO-mtl-0.3.1.0/html/MonadCatchIO-mtl.haddock
+haddock-html: /usr/local/share/doc/hs-MonadCatchIO-mtl-0.3.1.0/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
